;; Generated package description from keymap-popup.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "keymap-popup" "0.4.0.0.20260715.2" "Described keymaps with popup help" '((emacs "29.1")) :commit "44ee56b4de2756460a366c7fa45de6dbf7bee9fe" :authors '(("Thanos Apollo" . "public@thanosapollo.org")) :maintainer '("Thanos Apollo" . "public@thanosapollo.org") :keywords '("convenience") :url "https://codeberg.org/thanosapollo/emacs-keymap-popup")
